scatter_plot: Scatterplot for customplot

View source: R/scatter_plot.R

scatter_plotR Documentation

Scatterplot for customplot

Description

A pre-made scatter plot that can be added to the custom.plot parameter.

Usage

scatter_plot(mydata, x, y)

Arguments

mydata

A data set containing intersection data provided internally

x

The x aesthetic for the scatter plot

y

The y aesthetic for the scatter plot

Note

See examples section for upset function on how to use custom.plot parameter.


UpSetR documentation built on May 25, 2026, 5:06 p.m.